@@ -13,6 +13,9 @@ def json_force_parameter_type(funct):
             args = list(args)
         parameters = signature(funct).parameters
         for pi, p in enumerate(parameters):
+            if p in kwargs and type(kwargs[p]) is not parameters[p].annotation:
+                if type(kwargs[p]) is JsonObject:
+                    kwargs[p] = JsonObject.load()
             if issubclass(parameters[p].annotation, JsonObject) and parameters[p].annotation is not JsonObject:
                 if p in kwargs and isinstance(kwargs[p], JsonObject):
                     kwargs[p] = kwargs[p].into(parameters[p].annotation)
@@ -67,7 +70,11 @@ class JsonDate:
 
 class JsonObject:
 
-    def __init__(self, **kwargs):
+    def __init__(self, *args, **kwargs):
+        if args:
+            if type(args[0]) is str:
+                parsed = JsonObject.load(args[0])
+                JsonObject.__init__(self, **parsed.to_dict())
         if type(self) is JsonObject:
             for key, value in kwargs.items():
                 setattr(self, key, value)
